@@ -111,7 +111,7 @@ def generate_layer(template: TemplateInfo, layer: dict, tmp_path: Path, repo_pat
                 print(f"Missing config for '{key}', using default value of {value}")
             data[key] = value
 
-    out_dir = tmp_path / "build" / f"layer-{layer['name']}"
+    out_dir = tmp_path / "build" / f"layer-{layer['layer_name']}"
     out_dir.mkdir(parents=True)
     template_path = str(template.path)
     context["cookiecutter"]["_template"] = f"{repo_path}/{template.path.name}"
@@ -125,16 +125,21 @@ def generate_layer(template: TemplateInfo, layer: dict, tmp_path: Path, repo_pat
 
 def do_build(template_collection: TemplateCollection, args):
     output = Path(args.output)
+    if not output.is_dir():
+        print(f"Missing output directory {output}", file=sys.stderr)
+        return 1
     if args.config:
         print(f"Doing a fresh build.  Output will be written under {output}")
         config = json.load(args.config)
     else:
         config_file = output / ".crispycookie.json"
         if not config_file.is_file():
-            print("Missing {config} file.  Refusing to rebuild {output.name}", file=sys.stderr)
+            print(f"Missing {config_file} file.  Refusing to rebuild {output.name}", file=sys.stderr)
             return 1
         print(f"Regenerating a project {output.name} from existing {config_file.name}")
         # This seems silly, but to keep with the existing convention
+        if output.name == "":
+            output = output.absolute()
         output = output.parent
         with open(config_file) as f:
             config = json.load(f)
